@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Eucalyptus Systems, Inc.
+# Copyright (c) 2009-2016 Hewlett Packard Enterprise Development LP
 #
 # Redistribution and use of this software in source and binary forms,
 # with or without modification, are permitted provided that the following
@@ -27,9 +27,9 @@ import os.path
 import subprocess
 
 
-__version__ = '3.1.0'
+__version__ = '3.3-devel'
 
-BUFSIZE = 8192
+BUFSIZE = 16 * 1024
 
 
 if '__file__' in globals():
