@@ -110,6 +110,15 @@ def ec2_block_device_mapping(map_as_str):
     return map_dict
 
 
+def flexible_bool(bool_str):
+    if bool_str.strip().lower() in ('0', 'f', 'false', 'n', 'no'):
+        return False
+    if bool_str.strip().lower() in ('1', 't', 'true', 'y', 'yes'):
+        return True
+    raise argparse.ArgumentTypeError("'{0}' must be 'true' or 'false'"
+                                     .format(bool_str))
+
+
 def filesize(size):
     suffixes = 'kmgt'
     s_size = size.lower().rstrip('b')
@@ -247,8 +256,12 @@ def binary_tag_def(tag_str):
      - 'key=':      {'Key': key, 'Value': EMPTY}
      - 'key':       {'Key': key, 'Value': EMPTY}
     """
-    if '=' in tag_str:
+    if not tag_str:
+        raise ValueError('tag must be non-empty')
+    elif '=' in tag_str:
         (key, val) = tag_str.split('=', 1)
+        if not key:
+            raise ValueError('tag "{0}" must include a key'.format(tag_str))
         return {'Key': key, 'Value': val or EMPTY}
     else:
         return {'Key': tag_str, 'Value': EMPTY}
@@ -271,10 +284,12 @@ def ternary_tag_def(tag_str):
 
 
 def delimited_list(delimiter, item_type=str):
-    def _concrete_delimited_list(list_as_str):
+    def _delimited_list(list_as_str):
         if isinstance(list_as_str, str) and len(list_as_str) > 0:
             return [item_type(item.strip()) for item in
                     list_as_str.split(delimiter) if len(item.strip()) > 0]
         else:
             return []
-    return _concrete_delimited_list
+    # Improve the output of argparse's TypeError/ValueError handling
+    _delimited_list.__name__ = '{0} list'.format(item_type.__name__)
+    return _delimited_list
