@@ -1,4 +1,4 @@
-# Copyright 2009-2014 Eucalyptus Systems, Inc.
+# Copyright (c) 2009-2016 Hewlett Packard Enterprise Development LP
 #
 # Redistribution and use of this software in source and binary forms,
 # with or without modification, are permitted provided that the following
@@ -24,6 +24,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import argparse
+import io
 from operator import itemgetter
 import os.path
 import six
@@ -31,22 +32,24 @@ import socket
 from string import Template
 import sys
 
+import lxml.etree
 from requestbuilder import Arg
-from requestbuilder.auth import QuerySigV2Auth
-from requestbuilder.exceptions import ArgumentError, AuthError
+import requestbuilder.auth.aws
+from requestbuilder.exceptions import ArgumentError, AuthError, ClientError
 from requestbuilder.mixins import TabifyingMixin
 from requestbuilder.request import AWSQueryRequest
 from requestbuilder.service import BaseService
+import requests.exceptions
 
 from euca2ools.commands import Euca2ools
 from euca2ools.exceptions import AWSError
-from euca2ools.util import substitute_euca_region
+from euca2ools.util import add_fake_region_name
 
 
 class EC2(BaseService):
     NAME = 'ec2'
     DESCRIPTION = 'Elastic compute cloud service'
-    API_VERSION = '2013-02-01'
+    API_VERSION = '2014-06-15'
     REGION_ENVVAR = 'AWS_DEFAULT_REGION'
     URL_ENVVAR = 'EC2_URL'
 
@@ -54,8 +57,8 @@ class EC2(BaseService):
                 help='compute service endpoint URL')]
 
     def configure(self):
-        substitute_euca_region(self)
-        BaseService.configure(self)
+        requestbuilder.service.BaseService.configure(self)
+        add_fake_region_name(self)
 
     def handle_http_error(self, response):
         raise AWSError(response)
@@ -64,7 +67,7 @@ class EC2(BaseService):
 class EC2Request(AWSQueryRequest, TabifyingMixin):
     SUITE = Euca2ools
     SERVICE_CLASS = EC2
-    AUTH_CLASS = QuerySigV2Auth
+    AUTH_CLASS = requestbuilder.auth.aws.HmacV4Auth
     METHOD = 'POST'
 
     def __init__(self, **kwargs):
@@ -92,12 +95,11 @@ class EC2Request(AWSQueryRequest, TabifyingMixin):
         instance_line = ['INSTANCE']
         for key in ['instanceId', 'imageId', 'dnsName', 'privateDnsName']:
             instance_line.append(instance.get(key))
-        instance_line.append(instance.get('instanceState', {})
-                                     .get('name'))
+        instance_line.append(instance.get('instanceState', {}).get('name'))
         instance_line.append(instance.get('keyName'))
         instance_line.append(instance.get('amiLaunchIndex'))
         instance_line.append(','.join([code['productCode'] for code in
-                             instance.get('productCodes', [])]))
+                                       instance.get('productCodes', [])]))
         instance_line.append(instance.get('instanceType'))
         instance_line.append(instance.get('launchTime'))
         instance_line.append(instance.get('placement', {}).get(
@@ -129,6 +131,7 @@ class EC2Request(AWSQueryRequest, TabifyingMixin):
         instance_line.append(instance.get('placement', {}).get('tenancy'))
         instance_line.append(instance.get('ebsOptimized'))
         instance_line.append(instance.get('iamInstanceProfile', {}).get('arn'))
+        instance_line.append(instance.get('architecture'))
         print self.tabify(instance_line)
 
         for blockdev in instance.get('blockDeviceMapping', []):
@@ -173,13 +176,39 @@ class EC2Request(AWSQueryRequest, TabifyingMixin):
     def print_vpc(self, vpc):
         print self.tabify(('VPC', vpc.get('vpcId'), vpc.get('state'),
                            vpc.get('cidrBlock'), vpc.get('dhcpOptionsId'),
-                           vpc.get('instanceTenancy')))
+                           vpc.get('instanceTenancy'), vpc.get('isDefault')))
         for tag in vpc.get('tagSet') or []:
             self.print_resource_tag(tag, vpc.get('vpcId'))
 
+    def print_internet_gateway(self, igw):
+        print self.tabify(('INTERNETGATEWAY', igw.get('internetGatewayId')))
+        for attachment in igw.get('attachmentSet') or []:
+            print self.tabify(('ATTACHMENT', attachment.get('vpcId'),
+                               attachment.get('state')))
+        for tag in igw.get('tagSet') or []:
+            self.print_resource_tag(tag, igw.get('internetGatewayId'))
+
+    def print_peering_connection(self, pcx):
+        status = pcx.get('status') or {}
+        print self.tabify(('VPCPEERINGCONNECTION',
+                           pcx.get('vpcPeeringConnectionId'),
+                           pcx.get('expirationTime'),
+                           '{0}: {1}'.format(status.get('code'),
+                                             status.get('message'))))
+        requester = pcx.get('requesterVpcInfo') or {}
+        print self.tabify(('REQUESTERVPCINFO', requester.get('vpcId'),
+                           requester.get('cidrBlock'),
+                           requester.get('ownerId')))
+        accepter = pcx.get('accepterVpcInfo') or {}
+        print self.tabify(('ACCEPTERVPCINFO', accepter.get('vpcId'),
+                           accepter.get('cidrBlock'), accepter.get('ownerId')))
+        for tag in pcx.get('tagSet') or []:
+            self.print_resource_tag(tag, pcx.get('vpcPeeringConnectionId'))
+
     def print_subnet(self, subnet):
         print self.tabify(('SUBNET', subnet.get('subnetId'),
                            subnet.get('state'), subnet.get('vpcId'),
+                           subnet.get('cidrBlock'),
                            subnet.get('availableIpAddressCount'),
                            subnet.get('availabilityZone'),
                            subnet.get('defaultForAz'),
@@ -248,12 +277,12 @@ class EC2Request(AWSQueryRequest, TabifyingMixin):
         nic_info = [nic.get(attr) for attr in (
             'networkInterfaceId', 'subnetId', 'vpcId', 'ownerId', 'status',
             'privateIpAddress', 'privateDnsName', 'sourceDestCheck')]
-        print self.tabify(['NIC'] + nic_info)
+        print self.tabify(['NETWORKINTERFACE'] + nic_info)
         if nic.get('attachment'):
             attachment_info = [nic['attachment'].get(attr) for attr in (
-                'attachmentID', 'deviceIndex', 'status', 'attachTime',
+                'attachmentId', 'deviceIndex', 'status', 'attachTime',
                 'deleteOnTermination')]
-            print self.tabify(['NICATTACHMENT'] + attachment_info)
+            print self.tabify(['ATTACHMENT'] + attachment_info)
         privaddresses = nic.get('privateIpAddressesSet', [])
         if nic.get('association'):
             association = nic['association']
@@ -267,14 +296,82 @@ class EC2Request(AWSQueryRequest, TabifyingMixin):
                     break
             else:
                 privaddress = None
-            print self.tabify(('NICASSOCIATION', association.get('publicIp'),
-                               association.get('ipOwnerId'), privaddress))
+            print self.tabify(('ASSOCIATION', association.get('publicIp'),
+                               association.get('ipOwnerId'),
+                               privaddress.get('privateIpAddress')))
         for group in nic.get('groupSet', []):
             print self.tabify(('GROUP', group.get('groupId'),
                                group.get('groupName')))
         for privaddress in privaddresses:
+            if privaddress.get('primary').lower() == 'true':
+                primary = 'primary'
+            else:
+                primary = None
             print self.tabify(('PRIVATEIPADDRESS',
-                               privaddress.get('privateIpAddress')))
+                               privaddress.get('privateIpAddress'),
+                               privaddress.get('privateDnsName'), primary))
+        for tag in nic.get('tagSet') or []:
+            self.print_resource_tag(tag, nic.get('networkInterfaceId'))
+
+    def print_customer_gateway(self, cgw):
+        print self.tabify(('CUSTOMERGATEWAY', cgw.get('customerGatewayId'),
+                           cgw.get('state'), cgw.get('type'),
+                           cgw.get('ipAddress'), cgw.get('bgpAsn')))
+        for tag in cgw.get('tagSet', []):
+            self.print_resource_tag(tag, cgw.get('customerGatewayId'))
+
+    def print_vpn_gateway(self, vgw):
+        print self.tabify(('VPNGATEWAY', vgw.get('vpnGatewayId'),
+                           vgw.get('state'), vgw.get('availabilityZone'),
+                           vgw.get('type')))
+        for attachment in vgw.get('attachments'):
+            print self.tabify(('VGWATTACHMENT', attachment.get('vpcId'),
+                               attachment.get('state')))
+        for tag in vgw.get('tagSet', []):
+            self.print_resource_tag(tag, vgw.get('vpnGatewayId'))
+
+    def print_vpn_connection(self, vpn, show_conn_info=False,
+                             stylesheet=None):
+        print self.tabify(('VPNCONNECTION', vpn.get('vpnConnectionId'),
+                           vpn.get('type'), vpn.get('customerGatewayId'),
+                           vpn.get('vpnGatewayId'), vpn.get('state')))
+        if show_conn_info and vpn.get('customerGatewayConfiguration'):
+            if stylesheet is None:
+                print vpn.get('customerGatewayConfiguration')
+            else:
+                if (stylesheet.startswith('http://') or
+                        stylesheet.startswith('https://')):
+                    self.log.info('fetching connection info stylesheet from %s',
+                                  stylesheet)
+                    response = requests.get(stylesheet)
+                    try:
+                        response.raise_for_status()
+                    except requests.exceptions.HTTPError as err:
+                        raise ClientError('failed to fetch stylesheet: {0}'
+                                          .format(str(err)))
+                    xslt_root = lxml.etree.XML(response.text)
+                else:
+                    if stylesheet.startswith('file://'):
+                        stylesheet = stylesheet[7:]
+                    self.log.info('using connection info stylesheet %s',
+                                  stylesheet)
+                    with open(stylesheet) as stylesheet_file:
+                        xslt_root = lxml.etree.parse(stylesheet_file)
+                transform = lxml.etree.XSLT(xslt_root)
+                conn_info_root = lxml.etree.parse(io.BytesIO(
+                    vpn.get('customerGatewayConfiguration')))
+                print transform(conn_info_root)
+        for tag in vpn.get('tagSet') or []:
+            self.print_resource_tag(tag, vpn.get('vpnConnectionId'))
+
+    def print_dhcp_options(self, dopt):
+        print self.tabify(('DHCPOPTIONS', dopt.get('dhcpOptionsId')))
+        for option in dopt.get('dhcpConfigurationSet') or {}:
+            values = [val_dict.get('value')
+                      for val_dict in option.get('valueSet')]
+            print self.tabify(('OPTION', option.get('key'), ','.join(values)))
+        for tag in dopt.get('tagSet', []):
+            self.print_resource_tag(tag, dopt.get('dhcpOptionsId'))
 
     def print_volume(self, volume):
         vol_bits = ['VOLUME']
@@ -446,7 +543,7 @@ def parse_ports(protocol, port_range=None, icmp_type_code=None):
     # changes then please fix this.
     from_port = None
     to_port = None
-    if protocol in ('icmp', '1', 1):
+    if str(protocol).lower() in ('icmp', '1'):
         if port_range:
             raise ArgumentError('argument -p/--port-range: not compatible '
                                 'with protocol "{0}"'.format(protocol))
@@ -466,7 +563,7 @@ def parse_ports(protocol, port_range=None, icmp_type_code=None):
         if from_port < -1 or to_port < -1:
             raise ArgumentError('argument -t/--icmp-type-code: ICMP type, '
                                 'code must be at least -1')
-    elif protocol in ('tcp', '6', 6, 'udp', '13', 13, 'sctp', '132', 132):
+    elif str(protocol).lower() in ('tcp', '6', 'udp', '17'):
         if icmp_type_code:
             raise ArgumentError('argument -t/--icmp-type-code: not compatible '
                                 'with protocol "{0}"'.format(protocol))
