@@ -1,4 +1,4 @@
-# Copyright 2013-2014 Eucalyptus Systems, Inc.
+# Copyright 2013-2015 Eucalyptus Systems, Inc.
 #
 # Redistribution and use of this software in source and binary forms,
 # with or without modification, are permitted provided that the following
@@ -27,14 +27,14 @@ import os
 import sys
 
 from requestbuilder import Arg
-import requestbuilder.auth
+import requestbuilder.auth.aws
 from requestbuilder.mixins import TabifyingMixin
 from requestbuilder.request import AWSQueryRequest
 import requestbuilder.service
 
 from euca2ools.commands import Euca2ools
 from euca2ools.exceptions import AWSError
-from euca2ools.util import strip_response_metadata, substitute_euca_region
+from euca2ools.util import strip_response_metadata, add_fake_region_name
 
 
 class CloudWatch(requestbuilder.service.BaseService):
@@ -48,8 +48,8 @@ class CloudWatch(requestbuilder.service.BaseService):
                 help='instance monitoring service endpoint URL')]
 
     def configure(self):
-        substitute_euca_region(self)
         requestbuilder.service.BaseService.configure(self)
+        add_fake_region_name(self)
 
     def handle_http_error(self, response):
         raise AWSError(response)
@@ -58,7 +58,7 @@ class CloudWatch(requestbuilder.service.BaseService):
 class CloudWatchRequest(AWSQueryRequest, TabifyingMixin):
     SUITE = Euca2ools
     SERVICE_CLASS = CloudWatch
-    AUTH_CLASS = requestbuilder.auth.QuerySigV2Auth
+    AUTH_CLASS = requestbuilder.auth.aws.HmacV4Auth
     METHOD = 'POST'
 
     def parse_response(self, response):
